#
# spec file for package python-Markdown
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-Markdown
Version:        3.1.1
Release:        lp152.1.2
Summary:        Python implementation of Markdown
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://python-markdown.github.io/
Source:         https://files.pythonhosted.org/packages/source/M/Markdown/Markdown-%{version}.tar.gz
Patch0:         markdown-3.0-python37.patch
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires:       python-xml
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%ifpython2
# older python2 version provided the package in lowercase
Provides:       %{oldpython}-markdown = %{version}
Obsoletes:      %{oldpython}-markdown < %{version}
%endif
%python_subpackages

%description
This is a Python implementation of John Gruber's [Markdown][].
It is almost completely compliant with the reference implementation,
though there are a few known issues. See [Features][] for information
on what exactly is supported and what is not. Additional features are
supported by the [Available Extensions][].

%prep
%setup -q -n Markdown-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/markdown_py

%check
%python_exec -m unittest discover

%post
%python_install_alternative markdown_py

%postun
%python_uninstall_alternative markdown_py

%files %{python_files}
%license LICENSE.md
%doc README.md docs/*
%python_alternative %{_bindir}/markdown_py
%{python_sitelib}/Markdown-%{version}-py%{python_version}.egg-info
%{python_sitelib}/markdown

%changelog
* Tue May 21 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.1.1: bugfix release
  * Fixed import failure in setup.py when the source directory is
    not on sys.path (#823).
  * Prefer public packaging module to pkg_resources' private copy
    of it (#825).
* Tue Mar 26 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.1:
  * The following new features have been included in the release:
    + A Contributing Guide has been added (#732)
    + A new configuration option to set the footnote separator has
    been added. Also, the rel and rev attributes have been
    removed from footnotes as they are not valid in HTML5. The
    refs and backrefs classes already exist and serve the same
    purpose (#723).
    + A new option for toc_depth to set not only the bottom section
    level, but also the top section level. A string consisting of
    two digits separated by a hyphen in between ("2-5"), defines
    the top (t) and the bottom (b) (<ht>..<hb>). A single integer
    still defines the bottom section level (<h1>..<hb>) only.(#787)
  * The following bug fixes are included in the 3.1 release:
    + Update CLI to support PyYAML 5.1.
    + Overlapping raw HTML matches no longer leave placeholders
    behind (#458).
    + Emphasis patterns now recognize newline characters as
    whitespace (#783).
    + Version format had been updated to be PEP 440 compliant
    (#736).
    + Block level elements are defined per instance, not as class
    attributes (#731).
    + Double escaping of block code has been eliminated (#725).
    + Problems with newlines in references has been fixed (#742).
    + Escaped # are now handled in header syntax (#762).
- remove yaml5.patch: merged upstream
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix build with PyYAML > 5:
  * yaml5.patch
* Wed Jan  2 2019 badshah400@gmail.com
- Update to version 3.0.1:
  * Brought back the `version` and `version_info` variables
    (gh#Python-Markdown/markdown#709).
  * Added support for hexadecimal HTML entities
    (gh#Python-Markdown/markdown#712).
* Mon Dec 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Thu Oct 18 2018 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.0: major release
  * backwards-incompatible changes:
    + enable_attributes keyword deprecated
    + smart_emphasis keyword and smart_strong extension deprecated
    + output_formats simplified to html and xhtml
    + safe_mode and html_replacement_text keywords deprecated
    + Positional arguments deprecated
    + Extension name behavior has changed
    + Extension configuration as part of extension name deprecated
    + HeaderId extension deprecated
    + Homegrown OrderedDict has been replaced with a purpose-built
    Registry
    + Markdown class instance references
    + markdown.util.isBlockLevel deprecated
    + md_globals keyword deprecated from extension API
    + Added new, more flexible InlineProcessor class
  * new features:
    + a new testing framework is included as a part of the Markdown
    library, which can also be used by third party extensions
    + a new toc_depth parameter has been added to the Table of
    Contents Extension
    +  new toc_tokens attribute has been added to the Markdown class
    by the Table of Contents Extension
    + when the Table of Contents Extension is used in conjunction
    with the Attribute Lists Extension and a data-toc-label
    attribute is defined on a header, the content of the
    data-toc-label attribute is now used as the content of the
    Table of Contents item for that header
    + additional CSS class names can be appended to Admonitions
- update and adapt the patch for python-3.7:
  * add markdown-3.0-python37.patch
  * remove markdown-2.6.11-python37.patch
- run the tests via unittest discover
- remove nose from BuildRequires: not used anymore
* Tue Aug  7 2018 tchvatal@suse.com
- Add patch to build with python 3.7:
  * markdown-2.6.11-python37.patch
* Mon Mar 19 2018 tchvatal@suse.com
- Add build/runtime dependency over setuptools wrt bsc#1079287
- Remove python-devel dependency which is not really needed
* Fri Jan  5 2018 benoit.monin@gmx.fr
- update to version 2.6.11: bugfix release
  * Added a new BACKLINK-TITLE option to the footnote extension so
    that non-English users can provide a custom title to back links
    (see #610)
- additional changes from version 2.6.10: documentation update
- remove encoding conversion: fixed upstream
* Fri Aug 18 2017 benoit.monin@gmx.fr
- update to version 2.6.9: bugfix release
* Sun May  7 2017 benoit.monin@gmx.fr
- convert the package to singlespec
- call fdupes to fix duplicated files
- fix encoding of the single file with CR/LF:
  avoid python-bytecode-inconsistent-mtime in every other files
* Thu Jan 26 2017 benoit.monin@gmx.fr
- update to version 2.6.8: bugfix release
* Sat Sep 24 2016 benoit.monin@gmx.fr
- update to version 2.6.7: bugfix release
- change source url to files.pythonhosted.org
* Wed Mar 23 2016 benoit.monin@gmx.fr
- update to version 2.6.6: no upstream changelog
* Wed Nov 25 2015 benoit.monin@gmx.fr
- update to version 2.6.5: bugfix release
* Sat Nov  7 2015 benoit.monin@gmx.fr
- update to version 2.6.4: bugfix release
* Tue Oct 27 2015 benoit.monin@gmx.fr
- update to version 2.6.3: bugfix release
* Tue Apr 21 2015 benoit.monin@gmx.fr
- update to version 2.6.2: bugfix release
* Tue Mar 10 2015 benoit.monin@gmx.fr
- update to version 2.6.1: bugfix release
  The (new) yaml option has been removed from the Meta-Data
  Extension as it was buggy
* Fri Feb 20 2015 benoit.monin@gmx.fr
- update to version 2.6:
  * `safe_mode` Deprecated
  * Positional Arguments Deprecated
  * "Shortened" Extension Names Deprecated
  * Extension Configuration as Part of Extension Name Deprecated
  * HeaderId Extension Pending Deprecation
  * The `configs` Keyword is Deprecated
  * Official Support for PyPy
  * YAML Style Meta-Data
  * Table of Contents Extension Refactored
  * Pygments can now be disabled
  * Miscellaneous
* Mon Nov 24 2014 benoit.monin@gmx.fr
- update to version 2.5.2: bugfix release
* Fri Oct  3 2014 benoit.monin@gmx.fr
- update to version 2.5.1: bugfix release
* Tue Sep 16 2014 benoit.monin@gmx.fr
- update to version 2.5:
  * The force_linenos config key on the CodeHilite extension has
    been deprecated.
  * Both safe_mode and the associated html_replacement_text
    keywords will be deprecated in version 2.6.
  * Positional arguments on the markdown.Markdown() function are
    pending deprecation.
  * The builtin extensions did not require the full path to be
    provided. This behavior will be deprecated in version 2.6.
  * The previously documented method of appending the extension
    configs as a string to the extension name will be deprecated in
    version 2.6.
  * The Smarty extension has had a number of additional
    configuration settings added.
  * Named extensions can now point to any module and/or Class on
    your PYTHONPATH.
  * The extension configuration code has been refactored.
  * The command line interface now accepts a --extensions_config
    (or -c).
  * The amonition extension is no longer considered experimental.
  * Various bug fixes have been made.
- add python-PyYAML to BuildRequires: needed for tests
* Wed Jul  9 2014 i@marguerite.su
- fix conflicts with python3-Markdown
  * both use update-alternatives
* Mon May 26 2014 hpj@urpla.net
- disable tests for 11.1 and SLES 10 builds
* Mon Feb 17 2014 benoit.monin@gmx.fr
- update to version 2.4:
  * the "force_linenos" config setting of the CodeHilite extension
    has been marked as Deprecated.
  * URLs are no longer percent-encoded.
  * the Smarty Extension has been added, which implements
    SmartyPants.
  * the Table of Contents Extension now supports new permalink
    option for creating Sphinx-style anchor links.
  * it is now possible to enable Markdown formatting inside HTML
    blocks by appending `markdown=1` to opening tag attributes.
  * The code blocks now support emphasizing some of the code lines.
  * Various bug fixes have been made.
- fix CRLF in all files: upstream converted to DOS encoding
* Wed Jan 15 2014 benoit.monin@gmx.fr
- update to version 2.3.1:
  no changelog
- additional changes from version 2.3.0:
  * Support has been dropped for Python 2.5.
  * All classes are now "new-style" classes.
  * "safe_mode" has been further restricted.
  * The ids assigned to footnotes now contain a dash (`-`) rather
    than a colon (`:`) when `output_format` it set to "html5" or
    "xhtml5".
  * The "force_linenos" config setting of the CodeHilite extension
    has been marked as Pending Deprecation and a new setting
    "linenums" has been added to replace it.
  * The "RSS" extension has been removed.
  * The "HTML Tidy" Extension has been removed.
  * The entire code base now universally runs in Python 2 and
    Python 3 without any need for running the 2to3 conversion tool.
  * The Admonition Extension has been added.
  * Various bug fixes have been made.
- drop sed call to remove shebangs: fixed upstream
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 2.2.1:
  + Python-Markdown 2.2.1 is a bug-fix release. No new features have been added.
    However, at least one bug fix does not work in Python 2.4 so that version of
    Python is no longer supported. For a full list of changes, see the git log.
* Mon Jul 23 2012 saschpe@suse.de
- Initial version
